@@ -2,12 +2,16 @@ const wrapper = require('./TransmitterWrapper')
 
 class Transmitter {
 
+    static initialize() {
+        return wrapper.initialize()
+    }
+
    static sendCommand(messageArray) {
         return wrapper.sendCommand(messageArray)
     }
 
-    static activate = function(licenseKey = "") {
-        return wrapper.activate(licenseKey, "", "", "")
+    static activate = function(licenseKey) {
+        return wrapper.activate(licenseKey)
     }
 
     static setConfigSource(configSource) {
